/***************************************************************************
                          kplspinbox.cpp  -  description
                             -------------------
    begin                : Fri Sep 8 2000
    copyright            : (C) 2002 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kplspinbox.h"

KplSpinBox::KplSpinBox(int _minValue, int _maxValue, int step,
                       QWidget* _parent, const char* _name) :
 QSpinBox(_minValue, _maxValue, step, _parent, _name)
{
}

KplSpinBox::~KplSpinBox()
{
}

int KplSpinBox::interpretedValue()
{
  interpretText();
  return QRangeControl::value();
}
